print("import: 'numpy'")
import numpy

print("import: 'numpy.core.multiarray'")
import numpy.core.multiarray

print("import: 'numpy.core.numeric'")
import numpy.core.numeric

print("import: 'numpy.core.umath'")
import numpy.core.umath

print("import: 'numpy.linalg.lapack_lite'")
import numpy.linalg.lapack_lite

print("import: 'numpy.random.mtrand'")
import numpy.random.mtrand

